@@ -29,6 +29,7 @@
 #undef GDK_MULTIHEAD_SAFE
 #endif
 
+#include "netk-private.h"
 #include "netk-pager.h"
 #include "netk-workspace.h"
 #include "netk-window.h"
@@ -120,31 +121,20 @@ static GObjectClass *parent_class;
 GType
 netk_pager_get_type (void)
 {
-    static GType object_type = 0;
+    static GType type = G_TYPE_INVALID;
 
-    g_type_init ();
-
-    if (!object_type)
+    if (G_UNLIKELY (type == G_TYPE_INVALID))
     {
-        static const GTypeInfo object_info = {
-            sizeof (NetkPagerClass),
-            (GBaseInitFunc) NULL,
-            (GBaseFinalizeFunc) NULL,
-            (GClassInitFunc) netk_pager_class_init,
-            NULL,               /* class_finalize */
-            NULL,               /* class_data */
-            sizeof (NetkPager),
-            0,                  /* n_preallocs */
-            (GInstanceInitFunc) netk_pager_init,
-            NULL		/* value_table */
-        };
-
-        object_type =
-            g_type_register_static (GTK_TYPE_WIDGET, "NetkPager",
-                                    &object_info, 0);
+        type = _netk_g_type_register_simple (GTK_TYPE_WIDGET,
+                                             "NetkPager",
+                                             sizeof (NetkPagerClass),
+                                             netk_pager_class_init,
+                                             sizeof (NetkPager),
+                                             netk_pager_init,
+                                             0);                                    
     }
 
-    return object_type;
+    return type;
 }
 
 static void
