@@ -111,7 +111,7 @@ xfce_file_chooser_new_valist(const gchar *title, GtkWindow *parent,
 #if GTK_CHECK_VERSION(2, 4, 0)
 
 	chooser = XFCE_FILE_CHOOSER(gtk_file_chooser_dialog_new(title, parent,
-			action, NULL));
+			action, NULL, NULL));
 	
 	if(first_button_text) {
 		const gchar *text = first_button_text;
@@ -176,7 +176,7 @@ xfce_file_chooser_new_valist(const gchar *title, GtkWindow *parent,
  * @...: Response ID for the first button, followed by additional (button, ID)
  *       pairs, terminated with a %NULL argument.
  *
- * Deprecated: Use xfce_file_chooser_new() instead.
+ * Deprecated: Use GtkFileChooser instead.
  *
  * Return value: a new #XfceFileChooser dialog widget.
  **/
@@ -210,6 +210,8 @@ xfce_file_chooser_dialog_new(const gchar *title, GtkWindow *parent,
  * For GTK+ 2.0 and 2.2, this creates a
  * <ulink url="http://developer.gnome.org/doc/API/2.0/gtk/GtkFileSelection.html">GtkFileSelection</ulink>.
  *
+ * Deprecated: Use GtkFileChooser instead.
+ *
  * Since 4.1
  *
  * Return value: a new #XfceFileChooser dialog widget.
@@ -236,6 +238,8 @@ xfce_file_chooser_new(const gchar *title, GtkWindow *parent,
  *
  * Sets whether multiple files can be selected in the file chooser.
  *
+ * Deprecated: Use GtkFileChooser instead.
+ *
  * Since 4.1
  **/
 void
@@ -256,6 +260,8 @@ xfce_file_chooser_set_select_multiple(XfceFileChooser *chooser,
  * Gets whether multiple files can be selected in the file chooser.  See
  * xfce_file_chooser_set_select_multiple().
  *
+ * Deprecated: Use GtkFileChooser instead.
+ *
  * Since 4.1
  *
  * Return value: %TRUE if multiple files can be selected, %FALSE otherwise.
@@ -282,6 +288,8 @@ xfce_file_chooser_get_select_multiple(XfceFileChooser *chooser)
  * To preselect a particular existing filename, see
  * xfce_file_chooser_set_filename().
  *
+ * Deprecated: Use GtkFileChooser instead.
+ *
  * Since 4.1
  **/
 void
@@ -301,6 +309,8 @@ xfce_file_chooser_set_current_name(XfceFileChooser *chooser, const gchar *name)
  * Returns the currently selected file in the file chooser.  If multiple files
  * are selected, behavior is indeterminate.
  *
+ * Deprecated: Use GtkFileChooser instead.
+ *
  * Since 4.1
  *
  * Return value: The currently selected filename, or %NULL if no file is
@@ -329,6 +339,8 @@ xfce_file_chooser_get_filename(XfceFileChooser *chooser)
  * directory change.  If you wish to suggest a file name to the user, use
  * xfce_file_chooser_set_current_name() instead.
  *
+ * Deprecated: Use GtkFileChooser instead.
+ *
  * Since 4.1
  *
  * Return value: %TRUE if the file exists and was selected, %FALSE otherwise.
@@ -358,6 +370,8 @@ xfce_file_chooser_set_filename(XfceFileChooser *chooser, const gchar *filename)
  * use when xfce_file_chooser_set_select_multiple() is used to allow the
  * selection of multiple files.
  *
+ * Deprecated: Use GtkFileChooser instead.
+ *
  * Since 4.1
  *
  * Return value: A <ulink url="http://developer.gnome.org/doc/API/2.0/glib/glib-Singly-Linked-Lists.html">GSList</ulink>
@@ -393,6 +407,8 @@ xfce_file_chooser_get_filenames(XfceFileChooser *chooser)
  *
  * Sets the current folder of @chooser to @filename.
  *
+ * Deprecated: Use GtkFileChooser instead.
+ *
  * Since 4.1
  *
  * Return value: %TRUE if the folder exists and could be changed, %FALSE
@@ -419,6 +435,8 @@ xfce_file_chooser_set_current_folder(XfceFileChooser *chooser,
  *
  * Gets the current folder visible in the file chooser.
  *
+ * Deprecated: Use GtkFileChooser instead.
+ *
  * Since 4.1
  *
  * Return value: The currently-selected folder.  Release with g_free() when no
@@ -454,6 +472,8 @@ xfce_file_chooser_get_current_folder(XfceFileChooser *chooser)
  * Finally, use xfce_file_chooser_set_preview_widget_active() to tell the file
  * chooser whether or not a preview should be shown for that file.
  *
+ * Deprecated: Use GtkFileChooser instead.
+ *
  * Since 4.1
  **/
 void
@@ -508,6 +528,8 @@ xfce_file_chooser_set_preview_widget(XfceFileChooser *chooser,
  *
  * Retrieves the preview widget set by xfce_file_chooser_set_preview_widget().
  *
+ * Deprecated: Use GtkFileChooser instead.
+ *
  * Since 4.1
  *
  * Return value: A <ulink url="http://developer.gnome.org/dock/API/2.0/gtk/GtkWidget.html">GtkWidget</ulink>,
@@ -533,6 +555,8 @@ xfce_file_chooser_get_preview_widget(XfceFileChooser *chooser)
  * updating.  Unfortunately, this method limits the application to a single
  * callback function, but this should be sufficient for most uses.
  *
+ * Deprecated: Use GtkFileChooser instead.
+ *
  * Since 4.1
  **/
 void
@@ -554,6 +578,8 @@ xfce_file_chooser_set_preview_callback(XfceFileChooser *chooser,
  * xfce_file_chooser_set_preview_widget().  This should be used in the preview
  * callback every time the selected file is changed.
  *
+ * Deprecated: Use GtkFileChooser instead.
+ *
  * Since 4.1
  **/
 void
@@ -581,6 +607,8 @@ xfce_file_chooser_set_preview_widget_active(XfceFileChooser *chooser,
  * Gets whether or not the preview widget is displayed for the current file.
  * See xfce_file_chooser_set_preview_widget_active().
  *
+ * Deprecated: Use GtkFileChooser instead.
+ *
  * Since 4.1
  *
  * Return value: %TRUE if the preview widget is active, %FALSE otherwise.
@@ -609,6 +637,8 @@ xfce_file_chooser_get_preview_widget_active(XfceFileChooser *chooser)
  * Sets whether the file chooser should display a text label above the preview
  * widget containing the name of the selected file.
  *
+ * Deprecated: Use GtkFileChooser instead.
+ *
  * Since 4.1
  **/
 void
@@ -631,6 +661,8 @@ xfce_file_chooser_set_use_preview_label(XfceFileChooser *chooser,
  * Sets a widget to display in the file chooser to provide extra options to the
  * user.
  *
+ * Deprecated: Use GtkFileChooser instead.
+ *
  * Since 4.1
  **/
 void
@@ -666,6 +698,8 @@ xfce_file_chooser_set_extra_widget(XfceFileChooser *chooser,
  *
  * Gets the widget set with xfce_file_chooser_set_extra_widget().
  *
+ * Deprecated: Use GtkFileChooser instead.
+ *
  * Since 4.1
  *
  * Return value: The extra <ulink url="http://developer.gnome.org/doc/API/2.0/gtk/GtkWidget.html">GtkWidget</ulink>.
@@ -691,6 +725,8 @@ xfce_file_chooser_get_extra_widget(XfceFileChooser *chooser)
  * Note: This currently does nothing when libxfcegui4 is compiled against GTK+
  * 2.2 or lower.
  *
+ * Deprecated: Use GtkFileChooser instead.
+ *
  * Since 4.1
  **/
 void
@@ -713,6 +749,8 @@ xfce_file_chooser_add_filter(XfceFileChooser *chooser, XfceFileFilter *filter)
  * Note: This currently does nothing when libxfcegui4 is compiled against GTK+
  * 2.2 or lower.
  *
+ * Deprecated: Use GtkFileChooser instead.
+ *
  * Since 4.1
  **/
 void
@@ -736,6 +774,8 @@ xfce_file_chooser_remove_filter(XfceFileChooser *chooser, XfceFileFilter *filter
  * Note: This currently does nothing when libxfcegui4 is compiled against GTK+
  * 2.2 or lower.
  *
+ * Deprecated: Use GtkFileChooser instead.
+ *
  * Since 4.1
  **/
 void
@@ -758,7 +798,7 @@ xfce_file_chooser_set_filter(XfceFileChooser *chooser, XfceFileFilter *filter)
  * Sets whether or not the file chooser can display and/or allow the selection
  * of non-local files.
  *
- * Deprecated: This function isn't really useful in the context of Xfce.
+ * Deprecated: Use GtkFileChooser instead.
  *
  * Since 4.1
  **/
@@ -780,7 +820,7 @@ xfce_file_chooser_set_local_only(XfceFileChooser *chooser, gboolean local_only)
  * Gets whether or not the file chooser can display and/or allow the selection
  * of non-local files.
  *
- * Deprecated: This function isn't really useful in the context of Xfce.
+ * Deprecated: Use GtkFileChooser instead.
  *
  * Since 4.1
  *
@@ -809,6 +849,8 @@ xfce_file_chooser_get_local_only(XfceFileChooser *chooser)
  * Note: This currently does nothing when libxfcegui4 is compiled against GTK+
  * 2.2 or lower.
  *
+ * Deprecated: Use GtkFileChooser instead.
+ *
  * Since 4.1
  *
  * Return value: %TRUE if the folder given is valid, %FALSE otherwise.  If
@@ -838,6 +880,8 @@ xfce_file_chooser_add_shortcut_folder(XfceFileChooser *chooser,
  * Note: This currently does nothing when libxfcegui4 is compiled against GTK+
  * 2.2 or lower.
  *
+ * Deprecated: Use GtkFileChooser instead.
+ *
  * Since 4.1
  *
  * Return value: %TRUE if the removal succeeded, %FALSE otherwise.  If @error is
@@ -866,6 +910,8 @@ xfce_file_chooser_remove_shortcut_folder(XfceFileChooser *chooser,
  * Note: this will always return %NULL when libxfcegui4 is compiled against GTK+
  * 2.2 or below, as file filters are not supported.
  *
+ * Deprecated: Use GtkFileFilter instead.
+ *
  * Since 4.1
  *
  * Return value: An #XfceFileFilter, or %NULL (GTK+ 2.2 and below).
@@ -891,6 +937,8 @@ xfce_file_filter_new()
  * Note: this function has no effect when libxfcegui4 is compiled against GTK+
  * 2.2 or below, as file filters are not supported.
  *
+ * Deprecated: Use GtkFileFilter instead.
+ *
  * Since 4.1
  **/
 void
@@ -912,6 +960,8 @@ xfce_file_filter_set_name(XfceFileFilter *filter, const gchar *name)
  * Note: this function has no effect when libxfcegui4 is compiled against GTK+
  * 2.2 or below, as file filters are not supported.
  *
+ * Deprecated: Use GtkFileFilter instead.
+ *
  * Since 4.1
  **/
 void
@@ -934,6 +984,8 @@ xfce_file_filter_add_mime_type(XfceFileFilter *filter, const gchar *mime_type)
  * Note: this function has no effect when libxfcegui4 is compiled against GTK+
  * 2.2 or below, as file filters are not supported.
  *
+ * Deprecated: Use GtkFileFilter instead.
+ *
  * Since 4.1
  **/
 void
